=======
Credits
=======

Development Lead
----------------

* Lowell Alleman <lowell@kintyre.co>
* Alessandro Braidotti <alessandro@kintyre.co>

Contributors
------------

* Luke Murphey wrote the ``rest_handler.py`` module (MIT license)
